@@ -65,6 +65,33 @@ class Box:
             boxes.append(box)
         return boxes
 
-    GetBoxes=staticmethod(GetBoxes)    
+    GetBoxes=staticmethod(GetBoxes)
+
+
+    def GetBoxNames(repodir):
+        '''Returns a list of box names from filesystem'''
+        try:
+            repolist=os.listdir(repodir)
+        except IOError, e:
+            sys.exit('Cannot read directory "%s": %s' % (repodir,e[1]))
+        boxes=[]
+        boxlist={}
+        for boxid in sorted(repolist):
+            boxpath=repodir+os.sep+boxid
+            if os.path.isfile(boxpath):
+                continue
+            if not os.path.isdir(boxpath+os.sep+'journal'):
+                continue
+            boxdir=repodir+os.sep+boxid
+            subdirs=3
+            dirlength=2
+            compression='gzip'
+            boxstate='unknown'
+            boxdate='unknown'
+            box=Box(boxid,boxdir,subdirs,dirlength,compression,boxstate,boxdate)
+            boxes.append(box)
+        return boxes
+
+    GetBoxNames=staticmethod(GetBoxNames)
 
 
