@@ -3,6 +3,7 @@ import os
 import tarfile
 import Benno
 import socket
+import inspect
 
 # single instance
 try:
@@ -17,6 +18,12 @@ except socket.error as e:
 
 
 def fromConfig(configfile,args):
+    if args.tarfile and not args.list:
+        if args.tarfile=='-':
+            tar=tarfile.open(fileobj=sys.stdout,mode='w|')
+        else:
+            tar=tarfile.open(args.tarfile,'a')
+
     for container in Benno.Config(configfile).containers:
         if args.verbose > 0: print >> sys.stderr, "Backup container: %s" % container.id
         repo=container.getRepo()
@@ -43,7 +50,7 @@ def fromConfig(configfile,args):
             except IOError: pass
         if args.tarfile and not args.list:
             # tar output
-            newesthash=tarOutput(args,repo,oldhash,statusfile)
+            newesthash=tarOutput(args,repo,oldhash,statusfile,tar)
         else:
             # filename output
             newesthash=fileOutput(args,repo,oldhash,statusfile)
@@ -51,10 +58,20 @@ def fromConfig(configfile,args):
             f=open(statusfile,'w')
             f.write(newesthash+"\n")
             f.close()
+
+    try:
+        tar.close()
+    except UnboundLocalError: pass
     return 0
 
 
 def fromRepo(args):
+    if args.tarfile and not args.list:
+        if args.tarfile=='-':
+            tar=tarfile.open(fileobj=sys.stdout,mode='w|')
+        else:
+            tar=tarfile.open(args.tarfile,'a')
+
     repo=Benno.Repo(args.repo)
     if args.increment:
         statusfile=args.repo+os.sep+'backup.status'
@@ -78,14 +95,19 @@ def fromRepo(args):
         except IOError: pass
     if args.tarfile and not args.list:
         # tar output
-        newesthash=tarOutput(args,repo,oldhash,statusfile)
+        newesthash=tarOutput(tar,args,repo,oldhash,statusfile,tar)
     else:
         # filename output
         newesthash=fileOutput(args,repo,oldhash,statusfile)
+
     if statusfile:
         f=open(statusfile,'w')
         f.write(newesthash+"\n")
         f.close()
+
+    try:
+        tar.close()
+    except UnboundLocalError: pass
     return 0
 
 
@@ -100,20 +122,10 @@ def fileOutput(args,repo,oldhash,statusfile):
  
 
 ############################################################################
-def tarOutput(args,repo,oldhash,statusfile):
-    if args.tarfile=='-':
-        # open at first container
-        try:
-            tar
-        except NameError:
-            tar=tarfile.open(fileobj=sys.stdout,mode='w|')
-    else:
-        tar=tarfile.open(args.tarfile,'a')
+def tarOutput(args,repo,oldhash,statusfile,tar):
     newesthash=writeTar(repo,oldhash,args,tar)
     if statusfile and os.path.isfile(statusfile):
         tar.add(statusfile)
-    if not args.tarfile=='-':
-        tar.close()
     return newesthash
 
 
@@ -144,6 +156,7 @@ def writeTar(repo,oldhash,args,tar):
         for currenthash in mailhashes:
             if currenthash==oldhash:
                 return newesthash
+
             file2backup=jfile.box.fileFromHash(currenthash)
             path,repoFileName=file2backup.split(reposubdir)
             backupFileName=reposubdir+repoFileName
